@@ -4,7 +4,7 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    %{APPNAME} w;
+    %{APPNAMEID} w;
     w.show();
 
     return app.exec();
