@@ -1,26 +1,15 @@
-/***************************************************************************
- *   Copyright 2006 Hamish Rodda <rodda@kde.org>                           *
- *   Copyright 2007 Alexander Dymo  <adymo@kdevelop.org>                   *
- *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Alexander Dymo <adymo@kdevelop.org>
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef KDEVPLATFORM_IDOCUMENT_H
 #define KDEVPLATFORM_IDOCUMENT_H
 
+#include <QObject>
 #include <QUrl>
 #include <QScopedPointer>
 
@@ -40,6 +29,7 @@ class QWidget;
 
 namespace KDevelop {
 class ICore;
+class IDocumentPrivate;
 
 /**
  * A single document being edited by the IDE.
@@ -210,11 +200,14 @@ protected:
     void notifyLoaded();
 
 private:
-    const QScopedPointer<class IDocumentPrivate> d;
+    const QScopedPointer<class IDocumentPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(IDocument)
     friend class IDocumentPrivate;
 };
 
 }
 
+Q_DECLARE_INTERFACE(KDevelop::IDocument, "org.kdevelop.IDocument")
+
 #endif
 
