@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2007 Alexander Dymo  <adymo@kdevelop.org>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Alexander Dymo <adymo@kdevelop.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef KDEVPLATFORM_IUICONTROLLER_H
 #define KDEVPLATFORM_IUICONTROLLER_H
 
@@ -32,6 +20,7 @@ namespace Sublime{
     class Controller;
     class View;
     class Area;
+    class Message;
 }
 
 namespace KDevelop {
@@ -57,7 +46,7 @@ public:
     /**
      * @returns the default position where this tool view should appear
      */
-    virtual Qt::DockWidgetArea defaultPosition() = 0;
+    virtual Qt::DockWidgetArea defaultPosition() const = 0;
     /**
      * Fetch a list of actions to add to the toolbar of the tool view @p view
      * @param viewWidget the view to which the actions should be added
@@ -139,6 +128,19 @@ public:
       * @p message The message
       * @p timeout The timeout in seconds how long to show the message */
     virtual void showErrorMessage(const QString& message, int timeout = 1) = 0;
+    // TODO: convert all these calls into postMessage
+
+    /**
+     * Shows a message in the message area.
+     *
+     * If running in NoGui mode, the message will be discarded.
+     *
+     * Unlike all other functions in this class, this function is thread-safe.
+     * You can call it from the background.
+     *
+     * @p message the message, ownership is transferred
+     */
+    virtual void postMessage(Sublime::Message* message) = 0;
 
     /** @return area for currently active sublime mainwindow or 0 if
     no sublime mainwindow is active.*/
