@@ -1,23 +1,8 @@
 /*
- * This file is part of KDevelop
- *
- * Copyright 2010 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2010 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "documentchangetracker.h"
 
@@ -32,7 +17,7 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/MovingInterface>
 
-#include <QApplication>
+#include <QCoreApplication>
 
 // Can be used to disable the 'clever' updating logic that ignores whitespace-only changes and such.
 // #define ALWAYS_UPDATE
@@ -52,7 +37,7 @@ using namespace KTextEditor;
  *  - All changes within a local function (or function parameter context): Update only the context (and all its importers)
  *
  * @todo: Prevent recursive updates after insignificant changes
- *             (whitespace changes, or changes that don't affect publically visible stuff, eg. local incremental changes)
+ *             (whitespace changes, or changes that don't affect publicly visible stuff, eg. local incremental changes)
  *             -> Maybe alter the file-modification caches directly
  * */
 
@@ -313,7 +298,7 @@ RevisionLockerAndClearerPrivate::RevisionLockerAndClearerPrivate(DocumentChangeT
 {
     VERIFY_FOREGROUND_LOCKED
 
-        moveToThread(QApplication::instance()->thread());
+    moveToThread(QCoreApplication::instance()->thread());
 
     // Lock the revision
     m_tracker->lockRevision(revision);
@@ -499,3 +484,4 @@ RevisionReference DocumentChangeTracker::diskRevision() const
 }
 
 #include "documentchangetracker.moc"
+#include "moc_documentchangetracker.cpp"
