@@ -1,20 +1,8 @@
-/* This file is part of KDevelop
-    Copyright 2006-2008 Hamish Rodda <rodda@kde.org>
+/*
+    SPDX-FileCopyrightText: 2006-2008 Hamish Rodda <rodda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KDEVPLATFORM_ABSTRACTUSEBUILDER_H
 #define KDEVPLATFORM_ABSTRACTUSEBUILDER_H
@@ -201,9 +189,9 @@ protected:
             this->currentContext()->deleteUses();
 
             ContextUseTracker& tracker(currentUseTracker());
-            for (int a = 0; a < tracker.createUses.size(); ++a) {
-                this->currentContext()->createUse(tracker.createUses[a].m_declarationIndex,
-                                                  tracker.createUses[a].m_range);
+            for (auto& createUse : tracker.createUses) {
+                this->currentContext()->createUse(createUse.m_declarationIndex,
+                                                  createUse.m_range);
             }
         }
 
