@@ -51,16 +51,24 @@ DeclarationData::DeclarationData()
 {
 }
 
-///@todo Use reference counting
-static Repositories::StringRepository& commentRepository()
+struct DeclarationComment {
+};
+template <>
+class ItemRepositoryFor<DeclarationComment>
 {
-    static Repositories::StringRepository commentRepositoryObject(QStringLiteral("Comment Repository"));
-    return commentRepositoryObject;
-}
+    friend struct LockedItemRepository;
+    static auto& repo()
+    {
+        static QMutex mutex;
+        ///@todo Use reference counting
+        static Repositories::StringRepository repo(QStringLiteral("Comment Repository"), &mutex);
+        return repo;
+    }
+};
 
 void initDeclarationRepositories()
 {
-    commentRepository();
+    LockedItemRepository::initialize<DeclarationComment>();
 }
 
 Declaration::Kind Declaration::kind() const
@@ -166,22 +174,26 @@ QByteArray Declaration::comment() const
 {
     DUCHAIN_D(Declaration);
     if (!d->m_comment)
-        return nullptr;
-    else
-        return Repositories::arrayFromItem(commentRepository().itemFromIndex(d->m_comment));
+        return QByteArray();
+
+    return LockedItemRepository::read<DeclarationComment>([d](const Repositories::StringRepository& repo) {
+        return Repositories::arrayFromItem(repo.itemFromIndex(d->m_comment));
+    });
 }
 
 void Declaration::setComment(const QByteArray& str)
 {
     DUCHAIN_D_DYNAMIC(Declaration);
-    if (str.isEmpty())
+    if (str.isEmpty()) {
         d->m_comment = 0;
-    else
-        d->m_comment =
-            commentRepository().index(Repositories::StringRepositoryItemRequest(str.constData(),
-                                                                                IndexedString::hashString(str.constData(),
-                                                                                                          str.length()),
-                                                                                str.length()));
+        return;
+    }
+
+    const auto request = Repositories::StringRepositoryItemRequest(
+        str.constData(), IndexedString::hashString(str.constData(), str.length()), str.length());
+
+    d->m_comment = LockedItemRepository::write<DeclarationComment>(
+        [&](Repositories::StringRepository& repo) { return repo.index(request); });
 }
 
 void Declaration::setComment(const QString& str)
