@@ -1,20 +1,8 @@
 /*
-   Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KDEVPLATFORM_DUCHAINPOINTER_H
 #define KDEVPLATFORM_DUCHAINPOINTER_H
@@ -97,10 +85,8 @@ public:
     {
     }
 
-    DUChainPointer(const DUChainPointer& rhs)
-        : d(rhs.d)
-    {
-    }
+    DUChainPointer(const DUChainPointer&) = default;
+    DUChainPointer(DUChainPointer&&) = default;
 
     ///This constructor includes dynamic casting. If the object cannot be casted to the type, the constructed DUChainPointer will have value zero.
     template <class OtherType>
@@ -179,7 +165,8 @@ public:
         return static_cast<Type*>(d->base());
     }
 
-    DUChainPointer<Type>& operator=(const DUChainPointer<Type>& rhs) = default;
+    DUChainPointer<Type>& operator=(const DUChainPointer<Type>&) = default;
+    DUChainPointer<Type>& operator=(DUChainPointer<Type>&&) = default;
 
     DUChainPointer<Type>& operator=(Type* rhs)
     {
