@@ -7,6 +7,8 @@
 #include "instantiationinformation.h"
 #include "identifier.h"
 #include "serialization/itemrepository.h"
+#include "serialization/itemrepositoryreferencecounting.h"
+#include <serialization/repositorymanager.h>
 #include "types/typeutils.h"
 #include <typeinfo>
 #include "types/typealiastype.h"
@@ -117,23 +119,29 @@ uint InstantiationInformation::hash() const
     return kdevhash << previousInstantiationInformation.index();
 }
 
-AbstractRepositoryManager* returnTypeRepository()
-{
-    return typeRepositoryManager();
-}
+using InstantiationInformationRepository
+    = ItemRepository<InstantiationInformation, AppendedListItemRequest<InstantiationInformation>, true,
+                     QRecursiveMutex>;
+using InstantiationInformationRepositoryManager = RepositoryManager<InstantiationInformationRepository>;
 
-static KDevelop::RepositoryManager<KDevelop::ItemRepository<InstantiationInformation,
-        AppendedListItemRequest<InstantiationInformation>>>& instantiationInformationRepository()
+template <>
+class ItemRepositoryFor<IndexedInstantiationInformation>
 {
-    static KDevelop::RepositoryManager<KDevelop::ItemRepository<InstantiationInformation,
-            AppendedListItemRequest<InstantiationInformation>>> instantiationInformationRepositoryObject(QStringLiteral(
-            "Instantiation Information Repository"), 1, &returnTypeRepository);
-    return instantiationInformationRepositoryObject;
-}
+    friend struct LockedItemRepository;
+    static InstantiationInformationRepository& repo()
+    {
+        static InstantiationInformationRepositoryManager manager(QStringLiteral("Instantiation Information Repository"),
+                                                                 typeRepositoryMutex());
+        return *manager.repository();
+    }
+};
 
 uint standardInstantiationInformationIndex()
 {
-    static uint idx = instantiationInformationRepository()->index(InstantiationInformation());
+    static uint idx = LockedItemRepository::write<IndexedInstantiationInformation>(
+        [standardInstantiationInformation = InstantiationInformation()](InstantiationInformationRepository& repo) {
+            return repo.index(standardInstantiationInformation);
+        });
     return idx;
 }
 
@@ -142,51 +150,43 @@ void initInstantiationInformationRepository()
     standardInstantiationInformationIndex();
 }
 
-IndexedInstantiationInformation::IndexedInstantiationInformation() : m_index(0)
-{
-}
-
 IndexedInstantiationInformation::IndexedInstantiationInformation(uint index) : m_index(index)
 {
     if (m_index == standardInstantiationInformationIndex())
         m_index = 0;
 
-    if (m_index && shouldDoDUChainReferenceCounting(this)) {
-        QMutexLocker lock(instantiationInformationRepository()->mutex());
-        increase(instantiationInformationRepository()->dynamicItemFromIndexSimple(m_index)->m_refCount, m_index);
+    if (m_index) {
+        ItemRepositoryReferenceCounting::inc(this);
     }
 }
 
-IndexedInstantiationInformation::IndexedInstantiationInformation(const IndexedInstantiationInformation& rhs) : m_index(
-        rhs.m_index)
+// NOTE: the definitions of ItemRepositoryReferenceCounting's inc(), dec() and setIndex() are so
+// complex that they can throw exceptions for many reasons. Yet some special member functions of
+// IndexedInstantiationInformation, which call them, are implicitly (the destructor) or explicitly
+// noexcept. The noexcept-ness of these functions is important for correctness and performance.
+// This is safe at the moment, because the entire KDevPlatformLanguage library, that contains
+// IndexedInstantiationInformation, is compiled with exceptions disabled (-fno-exceptions), which
+// already prevents exception propagation to a caller of any non-inline function in this library.
+
+IndexedInstantiationInformation::IndexedInstantiationInformation(const IndexedInstantiationInformation& rhs) noexcept
+    : m_index(rhs.m_index)
 {
-    if (m_index && shouldDoDUChainReferenceCounting(this)) {
-        QMutexLocker lock(instantiationInformationRepository()->mutex());
-        increase(instantiationInformationRepository()->dynamicItemFromIndexSimple(m_index)->m_refCount, m_index);
+    if (m_index) {
+        ItemRepositoryReferenceCounting::inc(this);
     }
 }
 
-IndexedInstantiationInformation& IndexedInstantiationInformation::operator=(const IndexedInstantiationInformation& rhs)
+IndexedInstantiationInformation& IndexedInstantiationInformation::operator=(const IndexedInstantiationInformation& rhs) noexcept
 {
-    if (m_index && shouldDoDUChainReferenceCounting(this)) {
-        QMutexLocker lock(instantiationInformationRepository()->mutex());
-        decrease(instantiationInformationRepository()->dynamicItemFromIndexSimple(m_index)->m_refCount, m_index);
-    }
-
-    m_index = rhs.m_index;
-
-    if (m_index && shouldDoDUChainReferenceCounting(this)) {
-        QMutexLocker lock(instantiationInformationRepository()->mutex());
-        increase(instantiationInformationRepository()->dynamicItemFromIndexSimple(m_index)->m_refCount, m_index);
-    }
+    const auto checkIndex = [](unsigned int index) { return index != 0; };
+    ItemRepositoryReferenceCounting::setIndex(this, m_index, rhs.m_index, checkIndex);
     return *this;
 }
 
 IndexedInstantiationInformation::~IndexedInstantiationInformation()
 {
-    if (m_index && shouldDoDUChainReferenceCounting(this)) {
-        QMutexLocker lock(instantiationInformationRepository()->mutex());
-        decrease(instantiationInformationRepository()->dynamicItemFromIndexSimple(m_index)->m_refCount, m_index);
+    if (m_index) {
+        ItemRepositoryReferenceCounting::dec(this);
     }
 }
 
@@ -197,12 +197,16 @@ bool IndexedInstantiationInformation::isValid() const
 
 const InstantiationInformation& IndexedInstantiationInformation::information() const
 {
-    return *instantiationInformationRepository()->itemFromIndex(
-        m_index ? m_index : standardInstantiationInformationIndex());
+    auto index = m_index ? m_index : standardInstantiationInformationIndex();
+    // TODO: it's probably unsafe to return the const& here, as the repo won't be locked during access anymore
+    return *LockedItemRepository::read<IndexedInstantiationInformation>(
+        [index](const InstantiationInformationRepository& repo) { return repo.itemFromIndex(index); });
 }
 
 IndexedInstantiationInformation InstantiationInformation::indexed() const
 {
-    return IndexedInstantiationInformation(instantiationInformationRepository()->index(*this));
+    auto index = LockedItemRepository::write<IndexedInstantiationInformation>(
+        [this](InstantiationInformationRepository& repo) { return repo.index(*this); });
+    return IndexedInstantiationInformation(index);
 }
 }
