@@ -16,6 +16,9 @@
 #include <KLocalizedString>
 
 #include "../duchainlock.h"
+
+#include <util/widgetcolorizer.h>
+
 #include <debug.h>
 
 namespace {
@@ -85,13 +88,6 @@ void AbstractNavigationWidget::initBrowser(int height)
     Q_UNUSED(height);
     d->m_browser = new QTextBrowser;
 
-    // since we can embed arbitrary HTML we have to make sure it stays readable by forcing a black-white palette
-    QPalette p;
-    p.setColor(QPalette::AlternateBase, Qt::white);
-    p.setColor(QPalette::Base, Qt::white);
-    p.setColor(QPalette::Text, Qt::black);
-    d->m_browser->setPalette(p);
-
     d->m_browser->setOpenLinks(false);
     d->m_browser->setOpenExternalLinks(false);
 
@@ -204,6 +200,8 @@ void AbstractNavigationWidget::update()
 
         d->m_browser->setHtml(html);
 
+        WidgetColorizer::convertDocumentToDarkTheme(d->m_browser->document());
+
         d->m_currentText = html;
 
         d->m_idealTextSize = QSize();
@@ -266,8 +264,6 @@ void AbstractNavigationWidget::navigateDeclaration(const IndexedDeclaration& dec
 
 void AbstractNavigationWidgetPrivate::anchorClicked(const QUrl& url)
 {
-    DUChainReadLocker lock;
-
     //We may get deleted while the call to acceptLink, so make sure we don't crash in that case
     QPointer<AbstractNavigationWidget> thisPtr(q);
     NavigationContextPointer nextContext = m_context->acceptLink(url.toString());
