@@ -21,6 +21,10 @@
 #include "abstractitemrepository.h"
 #include "debug.h"
 
+#include <mutex>
+#include <set>
+#include <utility>
+
 using namespace KDevelop;
 
 namespace {
@@ -99,47 +103,31 @@ namespace KDevelop {
 class ItemRepositoryRegistryPrivate
 {
 public:
-    ItemRepositoryRegistry* m_owner;
-    bool m_shallDelete;
-    bool m_wasShutdown;
+    bool m_shallDelete = false;
+    bool m_wasShutdown = false;
     QString m_path;
-    QMap<AbstractItemRepository*, AbstractRepositoryManager*> m_repositories;
+    // TODO: is the order of repositories important? If not, store them in a QSet rather than std::set.
+    std::set<AbstractItemRepository*> m_repositories;
     QMap<QString, QAtomicInt*> m_customCounters;
     mutable QRecursiveMutex m_mutex;
 
-    explicit ItemRepositoryRegistryPrivate(ItemRepositoryRegistry* owner)
-        : m_owner(owner)
-        , m_shallDelete(false)
-        , m_wasShutdown(false)
-    {
-    }
-
-    void lockForWriting();
-    void unlockForWriting();
-    void deleteDataDirectory(const QString& path, bool recreate = true);
-
     /// @param path  A shared directory-path that the item-repositories are to be loaded from.
-    /// @returns     Whether the repository registry has been opened successfully.
-    ///              If @c false, then all registered repositories should have been deleted.
     /// @note        Currently the given path must reference a hidden directory, just to make sure we're
     ///              not accidentally deleting something important.
-    bool open(const QString& path);
+    explicit ItemRepositoryRegistryPrivate(const QString& path);
 
-    /// Close all contained repositories.
-    /// @warning The current state is not stored to disk.
-    void close();
+    QAtomicInt& customCounter(const QString& identity, int initialValue);
+    void lockForWriting();
+    void unlockForWriting();
+    void deleteDataDirectory(bool recreate = true);
 };
 
 //The global item-repository registry
 ItemRepositoryRegistry* ItemRepositoryRegistry::m_self = nullptr;
 
 ItemRepositoryRegistry::ItemRepositoryRegistry(const QString& repositoryPath)
-    : d_ptr(new ItemRepositoryRegistryPrivate(this))
+    : d_ptr(new ItemRepositoryRegistryPrivate(repositoryPath))
 {
-    Q_D(ItemRepositoryRegistry);
-
-    Q_ASSERT(!repositoryPath.isEmpty());
-    d->open(repositoryPath);
 }
 
 void ItemRepositoryRegistry::initialize(const QString& repositoryPath)
@@ -180,15 +168,20 @@ QRecursiveMutex& ItemRepositoryRegistry::mutex()
     return d->m_mutex;
 }
 
+QAtomicInt& ItemRepositoryRegistryPrivate::customCounter(const QString& identity, int initialValue)
+{
+    auto customCounterIt = m_customCounters.find(identity);
+    if (customCounterIt == m_customCounters.end()) {
+        customCounterIt = m_customCounters.insert(identity, new QAtomicInt(initialValue));
+    }
+    return **customCounterIt;
+}
+
 QAtomicInt& ItemRepositoryRegistry::customCounter(const QString& identity, int initialValue)
 {
     Q_D(ItemRepositoryRegistry);
 
-    auto customCounterIt = d->m_customCounters.find(identity);
-    if (customCounterIt == d->m_customCounters.end()) {
-        customCounterIt = d->m_customCounters.insert(identity, new QAtomicInt(initialValue));
-    }
-    return **customCounterIt;
+    return d->customCounter(identity, initialValue);
 }
 
 ///The global item-repository registry that is used by default
@@ -197,15 +190,16 @@ ItemRepositoryRegistry& globalItemRepositoryRegistry()
     return *ItemRepositoryRegistry::self();
 }
 
-void ItemRepositoryRegistry::registerRepository(AbstractItemRepository* repository, AbstractRepositoryManager* manager)
+void ItemRepositoryRegistry::registerRepository(AbstractItemRepository* repository)
 {
     Q_D(ItemRepositoryRegistry);
 
     QMutexLocker lock(&d->m_mutex);
-    d->m_repositories.insert(repository, manager);
+    d->m_repositories.insert(repository);
     if (!d->m_path.isEmpty()) {
+        // Locking the repository is documented as the caller's responsibility.
         if (!repository->open(d->m_path)) {
-            d->deleteDataDirectory(d->m_path);
+            d->deleteDataDirectory();
             qCritical() << "failed to open a repository";
             abort();
         }
@@ -256,52 +250,37 @@ void ItemRepositoryRegistry::unRegisterRepository(AbstractItemRepository* reposi
     Q_D(ItemRepositoryRegistry);
 
     QMutexLocker lock(&d->m_mutex);
-    Q_ASSERT(d->m_repositories.contains(repository));
-    repository->close();
-    d->m_repositories.remove(repository);
+    Q_ASSERT(d->m_repositories.count(repository) == 1);
+    d->m_repositories.erase(repository);
 }
 
 //After calling this, the data-directory may be a new one
-void ItemRepositoryRegistryPrivate::deleteDataDirectory(const QString& path, bool recreate)
+void ItemRepositoryRegistryPrivate::deleteDataDirectory(bool recreate)
 {
     QMutexLocker lock(&m_mutex);
 
-    //lockForWriting creates a file, that prevents any other KDevelop instance from using the directory as it is.
-    //Instead, the other instance will try to delete the directory as well.
-    lockForWriting();
-
-    bool result = QDir(path).removeRecursively();
+    bool result = QDir(m_path).removeRecursively();
     Q_ASSERT(result);
     Q_UNUSED(result);
     // Just recreate the directory then; leave old path (as it is dependent on appname and session only).
     if (recreate) {
-        QDir().mkpath(path);
+        QDir().mkpath(m_path);
     }
 }
 
-bool ItemRepositoryRegistryPrivate::open(const QString& path)
+ItemRepositoryRegistryPrivate::ItemRepositoryRegistryPrivate(const QString& path)
+    : m_path(path)
 {
-    QMutexLocker mlock(&m_mutex);
-    if (m_path == path) {
-        return true;
-    }
+    Q_ASSERT(!path.isEmpty());
 
     // Check if the repository shall be cleared
     if (shouldClear(path)) {
         qCWarning(SERIALIZATION) << QStringLiteral("The data-repository at %1 has to be cleared.").arg(path);
-        deleteDataDirectory(path);
+        deleteDataDirectory(false);
     }
 
     QDir().mkpath(path);
 
-    for (auto it = m_repositories.constBegin(), end = m_repositories.constEnd(); it != end; ++it) {
-        if (!it.key()->open(path)) {
-            deleteDataDirectory(path);
-            qCritical() << "failed to open a repository";
-            abort();
-        }
-    }
-
     QFile f(path + QLatin1String("/Counters"));
     if (f.open(QIODevice::ReadOnly)) {
         QDataStream stream(&f);
@@ -312,13 +291,9 @@ bool ItemRepositoryRegistryPrivate::open(const QString& path)
             stream >> counterName;
             int counterValue;
             stream >> counterValue;
-            m_owner->customCounter(counterName, 0) = counterValue;
+            customCounter(counterName, 0) = counterValue;
         }
     }
-
-    m_path = path;
-
-    return true;
 }
 
 void ItemRepositoryRegistry::store()
@@ -326,8 +301,9 @@ void ItemRepositoryRegistry::store()
     Q_D(ItemRepositoryRegistry);
 
     QMutexLocker lock(&d->m_mutex);
-    for (auto it = d->m_repositories.constBegin(), end = d->m_repositories.constEnd(); it != end; ++it) {
-        it.key()->store();
+    for (auto* repository : std::as_const(d->m_repositories)) {
+        std::scoped_lock repoLock(*repository);
+        repository->store();
     }
 
     QFile versionFile(d->m_path + QStringLiteral("/version_%1").arg(staticItemRepositoryVersion()));
@@ -358,8 +334,8 @@ void ItemRepositoryRegistry::printAllStatistics() const
     Q_D(const ItemRepositoryRegistry);
 
     QMutexLocker lock(&d->m_mutex);
-    for (auto it = d->m_repositories.constBegin(), end = d->m_repositories.constEnd(); it != end; ++it) {
-        AbstractItemRepository* repository = it.key();
+    for (auto* repository : std::as_const(d->m_repositories)) {
+        std::scoped_lock repoLock(*repository);
         qCDebug(SERIALIZATION) << "statistics in" << repository->repositoryName() << ":";
         qCDebug(SERIALIZATION) << repository->printStatistics();
     }
@@ -371,8 +347,8 @@ int ItemRepositoryRegistry::finalCleanup()
 
     QMutexLocker lock(&d->m_mutex);
     int changed = false;
-    for (auto it = d->m_repositories.constBegin(), end = d->m_repositories.constEnd(); it != end; ++it) {
-        AbstractItemRepository* repository = it.key();
+    for (auto* repository : std::as_const(d->m_repositories)) {
+        std::scoped_lock repoLock(*repository);
         int added = repository->finalCleanup();
         changed += added;
         qCDebug(SERIALIZATION) << "cleaned in" << repository->repositoryName() << ":" << added;
@@ -381,23 +357,15 @@ int ItemRepositoryRegistry::finalCleanup()
     return changed;
 }
 
-void ItemRepositoryRegistryPrivate::close()
-{
-    QMutexLocker lock(&m_mutex);
-
-    for (auto it = m_repositories.constBegin(), end = m_repositories.constEnd(); it != end; ++it) {
-        it.key()->close();
-    }
-
-    m_path.clear();
-}
-
 ItemRepositoryRegistry::~ItemRepositoryRegistry()
 {
-    Q_D(ItemRepositoryRegistry);
+    Q_D(const ItemRepositoryRegistry);
+
+    for (auto* repository : std::as_const(d->m_repositories)) {
+        std::scoped_lock repoLock(*repository);
+        repository->close();
+    }
 
-    QMutexLocker lock(&d->m_mutex);
-    d->close();
     for (QAtomicInt* counter : qAsConst(d->m_customCounters)) {
         delete counter;
     }
@@ -408,16 +376,18 @@ void ItemRepositoryRegistry::shutdown()
     Q_D(ItemRepositoryRegistry);
 
     QMutexLocker lock(&d->m_mutex);
-    QString path = d->m_path;
 
     // FIXME: we don't close since this can trigger crashes at shutdown
     //        since some items are still referenced, e.g. in static variables
+    // NOTE: ItemRepositoryRegistryPrivate::close() used to close all contained repositories and clear d->m_path
+    //       under d->m_mutex lock before its code was moved into ~ItemRepositoryRegistry().
+    //       If this closing is ever uncommented, d->m_path could be cleared after its use in the code below.
 //   d->close();
 
     if (d->m_shallDelete) {
-        d->deleteDataDirectory(path, false);
+        d->deleteDataDirectory(false);
     } else {
-        QFile::remove(path + QLatin1String("/crash_counter"));
+        QFile::remove(d->m_path + QLatin1String("/crash_counter"));
     }
 
     d->m_wasShutdown = true;
