@@ -10,8 +10,6 @@
 #include <QAction>
 #include <QtGlobal>
 
-#include <kconfigwidgets_version.h>
-
 #include "mainwindow.h"
 
 namespace KDevelop
@@ -35,9 +33,6 @@ private Q_SLOTS:
 private:
     QString loadCurrentScheme() const;
     void    saveCurrentScheme(const QString &name);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 67, 0)
-    QString currentDesktopDefaultScheme() const;
-#endif
 };
 
 }  // namespace KDevelop
