@@ -27,12 +27,12 @@
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KMessageBox_KDevCompat>
 #include <KProtocolInfo>
 #include <KRecentFilesAction>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 #include <KTextEditor/AnnotationInterface>
-#include <kio_version.h>
 
 #include <sublime/area.h>
 #include <sublime/message.h>
@@ -194,11 +194,7 @@ public:
         if (url.isLocalFile()) {
             return QFile::exists(url.toLocalFile());
         } else {
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
             auto job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
-#else
-            auto job = KIO::stat(url, KIO::StatJob::SourceSide, 0, KIO::HideProgressInfo);
-#endif
             KJobWidgets::setWindow(job, ICore::self()->uiController()->activeMainWindow());
             return job->exec();
         }
@@ -312,9 +308,16 @@ public:
                     doc = new PartDocument(url, Core::self());
                 } else
                 {
-                    int openAsText = KMessageBox::questionYesNo(nullptr, i18n("KDevelop could not find the editor for file '%1' of type %2.\nDo you want to open it as plain text?", url.fileName(), mimeType.name()), i18nc("@title:window", "Could Not Find Editor"),
-                                                                KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("AskOpenWithTextEditor"));
-                    if (openAsText == KMessageBox::Yes)
+                    int openAsText = KMessageBox::questionTwoActions(
+                        nullptr,
+                        i18n("KDevelop could not find the editor for file '%1' of type %2.\nDo you want to open it as "
+                             "plain text?",
+                             url.fileName(), mimeType.name()),
+                        i18nc("@title:window", "Could Not Find Editor"),
+                        KGuiItem(i18nc("@action:button", "Open as Plain Text"), QStringLiteral("text-plaim")),
+                        KGuiItem(i18nc("@action:button", "Do Not Open"), QStringLiteral("dialog-cancel")),
+                        QStringLiteral("AskOpenWithTextEditor"));
+                    if (openAsText == KMessageBox::PrimaryAction)
                         doc = new TextDocument(url, Core::self(), _encoding);
                     else
                         return nullptr;
