@@ -1,25 +1,13 @@
-/* This file is part of the KDevelop project
-Copyright 2003 Falk Brettschneider <falkbr@kdevelop.org>
-Copyright 2003 John Firebaugh <jfirebaugh@kde.org>
-Copyright 2003 Amilcar do Carmo Lucas <amilcar@kdevelop.org>
-Copyright 2004, 2007 Alexander Dymo <adymo@kdevelop.org>
-Copyright 2006 Adam Treat <treat@kde.org>
+/*
+    SPDX-FileCopyrightText: 2003 Falk Brettschneider <falkbr@kdevelop.org>
+    SPDX-FileCopyrightText: 2003 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2003 Amilcar do Carmo Lucas <amilcar@kdevelop.org>
+    SPDX-FileCopyrightText: 2004, 2007 Alexander Dymo <adymo@kdevelop.org>
+    SPDX-FileCopyrightText: 2006 Adam Treat <treat@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #ifndef KDEVPLATFORM_MAINWINDOW_H
 #define KDEVPLATFORM_MAINWINDOW_H
 
@@ -40,6 +28,7 @@ namespace KDevelop
 {
 
 class IDocument;
+class MainWindowPrivate;
 
 /**
 KDevelop main window.
@@ -109,7 +98,9 @@ private Q_SLOTS:
 private:
     void initializeCorners();
 
-    class MainWindowPrivate *d;
+private:
+    MainWindowPrivate* d_ptr;
+    Q_DECLARE_PRIVATE(MainWindow)
     friend class MainWindowPrivate;
 };
 
