@@ -13,7 +13,6 @@
 #include <KAboutData>
 #include <KActionCollection>
 #include <KActionMenu>
-#include <kcoreaddons_version.h>
 #include <KDialogJobUiDelegate>
 #include <KLocalizedString>
 #include <KSelectAction>
@@ -371,8 +370,6 @@ void RunController::initialize()
             this, &RunController::slotProjectOpened);
     connect(Core::self()->projectController(), &IProjectController::projectClosing,
             this, &RunController::slotProjectClosing);
-    connect(Core::self()->projectController(), &IProjectController::projectConfigurationChanged,
-             this, &RunController::slotRefreshProject);
 
     if( (Core::self()->setupFlags() & Core::NoUi) == 0 )
     {
@@ -518,12 +515,6 @@ void KDevelop::RunController::slotProjectClosing(KDevelop::IProject * project)
     }
 }
 
-void KDevelop::RunController::slotRefreshProject(KDevelop::IProject* project)
-{
-    slotProjectClosing(project);
-    slotProjectOpened(project);
-}
-
 void RunController::slotDebug()
 {
     Q_D(RunController);
@@ -606,11 +597,7 @@ void KDevelop::RunController::registerJob(KJob * job)
 
         connect( job, &KJob::finished, this, &RunController::finished );
         connect( job, &KJob::destroyed, this, &RunController::jobDestroyed );
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 80, 0)
-        connect(job, QOverload<KJob*, unsigned long>::of(&KJob::percent), this, &RunController::jobPercentChanged);
-#else
         connect(job, &KJob::percentChanged, this, &RunController::jobPercentChanged);
-#endif
 
         IRunController::registerJob(job);
 
