@@ -17,6 +17,8 @@
 #include <project/interfaces/iprojectfilemanager.h>
 #include <project/projectmodel.h>
 
+#include <QFileInfo>
+
 namespace KDevelop
 {
 
@@ -117,6 +119,13 @@ public:
         getImportsFromDUChain();
     }
 
+    void clear()
+    {
+        m_documents.clear();
+        m_imports.clear();
+        emit m_documentSet->changed();
+    }
+
 private:
     void getImportsFromDU(TopDUContext* context, QSet<TopDUContext*>& visitedContexts)
     {
@@ -275,7 +284,10 @@ void ProjectSet::fileAdded(ProjectFileItem* file)
 {
     Q_D(WatchedDocumentSet);
 
-    d->addDocument(IndexedString(file->indexedPath()), DoUpdate | DoEmit);
+    const auto path = IndexedString(file->indexedPath());
+    if (include(path)) {
+        d->addDocument(path, DoUpdate | DoEmit);
+    }
 }
 
 void ProjectSet::fileRemoved(ProjectFileItem* file)
@@ -290,7 +302,7 @@ void ProjectSet::fileRenamed(const Path& oldFile, ProjectFileItem* newFile)
     Q_D(WatchedDocumentSet);
 
     d->delDocument(IndexedString(oldFile.pathOrUrl()));
-    d->addDocument(IndexedString(newFile->indexedPath()), DoUpdate | DoEmit);
+    fileAdded(newFile);
 }
 
 void ProjectSet::trackProjectFiles(const IProject* project)
@@ -300,12 +312,12 @@ void ProjectSet::trackProjectFiles(const IProject* project)
         auto* fileManager = dynamic_cast<QObject*>(project->projectFileManager());
         if (fileManager) {
             // can't use new signal/slot syntax here, IProjectFileManager is no a QObject
-            connect(fileManager, SIGNAL(fileAdded(ProjectFileItem*)),
-                    this, SLOT(fileAdded(ProjectFileItem*)));
-            connect(fileManager, SIGNAL(fileRemoved(ProjectFileItem*)),
-                    this, SLOT(fileRemoved(ProjectFileItem*)));
-            connect(fileManager, SIGNAL(fileRenamed(Path,ProjectFileItem*)),
-                    this, SLOT(fileRenamed(Path,ProjectFileItem*)));
+            connect(fileManager, SIGNAL(fileAdded(KDevelop::ProjectFileItem*)), this,
+                    SLOT(fileAdded(KDevelop::ProjectFileItem*)));
+            connect(fileManager, SIGNAL(fileRemoved(KDevelop::ProjectFileItem*)), this,
+                    SLOT(fileRemoved(KDevelop::ProjectFileItem*)));
+            connect(fileManager, SIGNAL(fileRenamed(KDevelop::Path, KDevelop::ProjectFileItem*)), this,
+                    SLOT(fileRenamed(KDevelop::Path, KDevelop::ProjectFileItem*)));
         }
     }
 }
@@ -341,19 +353,43 @@ ProblemScope CurrentProjectSet::scope() const
 }
 
 AllProjectSet::AllProjectSet(QObject* parent)
+    : AllProjectSet(InitFlag::LoadOnInit, parent)
+{
+}
+
+AllProjectSet::AllProjectSet(InitFlag initFlag, QObject* parent)
     : ProjectSet(parent)
+{
+    switch (initFlag) {
+    case InitFlag::LoadOnInit:
+        reload();
+        break;
+    case InitFlag::SkipLoadOnInit:
+        break;
+    }
+}
+
+void AllProjectSet::reload()
 {
     Q_D(WatchedDocumentSet);
 
+    d->clear();
+
     const auto projects = ICore::self()->projectController()->projects();
     for (const IProject* project : projects) {
         const auto fileSet = project->fileSet();
         for (const IndexedString& indexedString : fileSet) {
-            d->addDocument(indexedString);
+            if (include(indexedString)) {
+                d->addDocument(indexedString);
+            }
+        }
+        const auto projectPath = IndexedString(project->path().toLocalFile());
+        if (include(projectPath)) {
+            d->addDocument(projectPath);
         }
-        d->addDocument(IndexedString(project->path().toLocalFile()));
         trackProjectFiles(project);
     }
+
     d->updateImports();
     emit changed();
 }
@@ -363,6 +399,52 @@ ProblemScope AllProjectSet::scope() const
     return AllProjects;
 }
 
+DocumentsInPathSet::DocumentsInPathSet(const QString& path, QObject* parent)
+    : AllProjectSet(InitFlag::SkipLoadOnInit, parent)
+    , m_path(path)
+{
+    reload();
+}
+
+ProblemScope DocumentsInPathSet::scope() const
+{
+    return DocumentsInPath;
+}
+
+void DocumentsInPathSet::setPath(const QString& path)
+{
+    if (m_path == path) {
+        return;
+    }
+
+    m_path = path;
+    reload();
+}
+
+bool DocumentsInPathSet::include(const IndexedString& path) const
+{
+    if (m_path.isEmpty()) {
+        return true;
+    }
+
+    return path.str().contains(m_path, Qt::CaseInsensitive);
+}
+
+DocumentsInCurrentPathSet::DocumentsInCurrentPathSet(const IndexedString& document, QObject* parent)
+    : DocumentsInPathSet(QFileInfo(document.str()).path(), parent)
+{
+}
+
+ProblemScope DocumentsInCurrentPathSet::scope() const
+{
+    return DocumentsInCurrentPath;
+}
+
+void DocumentsInCurrentPathSet::setCurrentDocument(const IndexedString& document)
+{
+    setPath(QFileInfo(document.str()).path());
+}
+
 BypassSet::BypassSet(QObject* parent)
     : WatchedDocumentSet(parent)
 {
@@ -376,3 +458,4 @@ ProblemScope BypassSet::scope() const
 }
 
 #include "watcheddocumentset.moc"
+#include "moc_watcheddocumentset.cpp"
