@@ -1,26 +1,12 @@
-/***************************************************************************
- *   This file was partly taken from KDevelop's cvs plugin                 *
- *   Copyright 2007 Robert Gruber <rgruber@users.sourceforge.net>          *
- *                                                                         *
- *   Adapted for DVCS (added templates)                                    *
- *   Copyright 2008 Evgeniy Ivanov <powerfox@kde.ru>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    This file was partly taken from KDevelop's cvs plugin
+    SPDX-FileCopyrightText: 2007 Robert Gruber <rgruber@users.sourceforge.net>
+
+    Adapted for DVCS (added templates)
+    SPDX-FileCopyrightText: 2008 Evgeniy Ivanov <powerfox@kde.ru>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef DVCS_PLUGIN_CC
 #define DVCS_PLUGIN_CC
@@ -142,3 +128,5 @@ void DistributedVersionControlPlugin::ctxBranchManager()
 }
 
 #endif
+
+#include "moc_dvcsplugin.cpp"
