@@ -1,23 +1,8 @@
 /*
- * This file is part of KDevelop
- *
- * Copyright 2010-2012,2020 Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2010-2012, 2020 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "checksetselectionmanager.h"
 
@@ -466,3 +451,5 @@ void CheckSetSelectionManager::onDefaultCheckSetSelectionChanged(const QString&
 }
 
 }
+
+#include "moc_checksetselectionmanager.cpp"
