@@ -12,6 +12,7 @@
 #include <QHash>
 #include <QDebug>
 #include <QDateTime>
+#include <QSet>
 
 #include <util/path.h>
 
@@ -43,10 +44,12 @@ struct KDEVCMAKECOMMON_EXPORT CMakeFile
 };
 Q_DECLARE_TYPEINFO(CMakeFile, Q_MOVABLE_TYPE);
 
-inline QDebug &operator<<(QDebug debug, const CMakeFile& file)
+inline QDebug operator<<(QDebug debug, const CMakeFile& file)
 {
-    debug << "CMakeFile(-I" << file.includes << ", -F" << file.frameworkDirectories << ", -D" << file.defines << ", " << file.language << ")";
-    return debug.maybeSpace();
+    const QDebugStateSaver saver(debug);
+    debug.nospace() << "CMakeFile(-I " << file.includes << ", -F " << file.frameworkDirectories << ", -D "
+                    << file.defines << ", " << file.language << ")";
+    return debug;
 }
 
 struct KDEVCMAKECOMMON_EXPORT CMakeFilesCompilationData
@@ -78,8 +81,11 @@ public:
 };
 Q_DECLARE_TYPEINFO(CMakeTarget, Q_MOVABLE_TYPE);
 
-inline QDebug &operator<<(QDebug debug, const CMakeTarget& target) {
-    debug << target.type << ':' << target.name; return debug.maybeSpace();
+inline QDebug operator<<(QDebug debug, const CMakeTarget& target)
+{
+    const QDebugStateSaver saver(debug);
+    debug.nospace() << target.type << ':' << target.name;
+    return debug;
 }
 
 inline bool operator==(const CMakeTarget& lhs, const CMakeTarget& rhs)
@@ -98,20 +104,22 @@ struct KDEVCMAKECOMMON_EXPORT CMakeTest
 };
 Q_DECLARE_TYPEINFO(CMakeTest, Q_MOVABLE_TYPE);
 
+struct PrintLastModified
+{
+    /// If not null, a prefix including this string is printed before formatted @a lastModified.
+    const char* const whatWasModified;
+    const QDateTime& lastModified;
+};
+QDebug KDEVCMAKECOMMON_EXPORT operator<<(QDebug debug, PrintLastModified p);
+
 struct KDEVCMAKECOMMON_EXPORT CMakeProjectData
 {
     CMakeFilesCompilationData compilationData;
     QHash<KDevelop::Path, QVector<CMakeTarget>> targets;
     QVector<CMakeTest> testSuites;
-    struct CMakeFileFlags
-    {
-        bool isGenerated = false;
-        bool isExternal = false;
-        bool isCMake = false;
-    };
-    QHash<KDevelop::Path, CMakeFileFlags> cmakeFiles;
-    QDateTime lastModifiedCMakeFile;
-    QDateTime lastModifiedProjectData;
+    /// Source CMake files (e.g. CMakeLists.txt, *.cmake), modifying which triggers reloading the project.
+    QSet<KDevelop::Path> cmakeFiles;
+    bool isOutdated = false;
 };
 
 #endif
