@@ -191,7 +191,7 @@ QString CustomScriptPlugin::formatSourceWithStyle(const SourceFormatterStyle& st
 
     int tabWidth = 4;
     if ((!leftContext.isEmpty() || !rightContext.isEmpty()) && (text.contains(QLatin1Char('	')) || output.contains(QLatin1Char('\t')))) {
-        // If we have to do contex-matching with tabs, determine the correct tab-width so that the context
+        // If we have to do context-matching with tabs, determine the correct tab-width so that the context
         // can be matched correctly
         const auto indent = indentation(style, url, mime);
         if (indent.indentationTabWidth > 0) {
@@ -319,7 +319,7 @@ KDevelop::SettingsWidget* CustomScriptPlugin::editStyleWidget(const QMimeType& m
     return new CustomScriptPreferences();
 }
 
-static QString formattingSample()
+static QString defaultSample()
 {
     return QStringLiteral(
         "// Formatting\n"
@@ -353,12 +353,9 @@ static QString formattingSample()
         "  }\n"
         "}\n"
         "}\n"
-        "}\n");
-}
+        "}\n"
 
-static QString indentingSample()
-{
-    return QStringLiteral(
+        "\n\n"
         "// Indentation\n"
         "#define foobar(A)\\\n"
         "{Foo();Bar();}\n"
@@ -418,7 +415,7 @@ QString CustomScriptPlugin::previewText(const SourceFormatterStyle& style, const
     if (!style.overrideSample().isEmpty()) {
         return style.overrideSample();
     }
-    return formattingSample() + QLatin1String("\n\n") + indentingSample();
+    return defaultSample();
 }
 
 QStringList CustomScriptPlugin::computeIndentationFromSample(const SourceFormatterStyle& style, const QUrl& url,
@@ -594,3 +591,4 @@ void CustomScriptPreferences::moreVariablesClicked(bool)
 }
 
 #include "customscript_plugin.moc"
+#include "moc_customscript_plugin.cpp"
