@@ -22,6 +22,7 @@
 #include <KActionMenu>
 #include <KJobWidgets>
 #include <KConfigGroup>
+#include <kio_version.h>
 
 #include <interfaces/icore.h>
 #include <interfaces/isession.h>
@@ -57,7 +58,11 @@ FileManager::FileManager(KDevFileManagerPlugin *plugin, QWidget* parent)
 
     l->addWidget(urlnav);
     dirop = new KDirOperator( urlnav->locationUrl(), this);
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     dirop->setView( KFile::Tree );
+#else
+    dirop->setViewMode(KFile::Tree);
+#endif
     dirop->setupMenu( KDirOperator::SortActions | KDirOperator::FileActions | KDirOperator::NavActions | KDirOperator::ViewActions );
     connect(dirop, &KDirOperator::urlEntered, this, &FileManager::updateNav);
     connect(dirop, &KDirOperator::contextMenuAboutToShow, this, &FileManager::fillContextMenu);
@@ -133,6 +138,8 @@ void FileManager::setupActions()
     action->setText(i18nc("@action switch to directory of current document", "Current Document Directory"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("dirsync")));
     connect(action, &QAction::triggered, this, &FileManager::syncCurrentDocumentDirectory);
+
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     auto* diropActionCollection = dirop->actionCollection();
     tbActions = {
         diropActionCollection->action(QStringLiteral("back")),
@@ -144,6 +151,18 @@ void FileManager::setupActions()
         action,
         diropActionCollection->action(QStringLiteral("sorting menu")),
         diropActionCollection->action(QStringLiteral("show hidden")),
+#else
+    tbActions = {
+        dirop->action(KDirOperator::Back),
+        dirop->action(KDirOperator::Up),
+        dirop->action(KDirOperator::Home),
+        dirop->action(KDirOperator::Forward),
+        dirop->action(KDirOperator::Reload),
+        acmBookmarks,
+        action,
+        dirop->action(KDirOperator::SortMenu),
+        dirop->action(KDirOperator::ShowHiddenFiles),
+#endif
     };
 
     newFileAction = new QAction(this);
