@@ -1,23 +1,11 @@
 #
 # LLDB data formatters for Qt types
-# Copyright 2016 Aetf <aetf@unlimitedcodeworks.xyz>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of
-# the License or (at your option) version 3 or any later version
-# accepted by the membership of KDE e.V. (or its successor approved
-# by the membership of KDE e.V.), which shall act as a proxy
-# defined in Section 14 of version 3 of the license.
+# SPDX-FileCopyrightText: 2016 Aetf <aetf@unlimitedcodeworks.xyz>
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #
+
 from __future__ import print_function
 
 import time
@@ -275,7 +263,7 @@ def QByteArraySummaryProvider(valobj, internal_dict):
         # Something wrong with our synthetic provider, get the content by ourselves
         printable, _, _ = printableQByteArray(valobj)
         if printable is not None:
-            # first replace " to \", and suround by "", no need to escape other things which
+            # first replace " to \", and surround by "", no need to escape other things which
             # are handled in printableQByteArray.
             return 'b"{}"'.format(printable.replace('"', '\\"'))
     return '<Invalid>'
@@ -300,7 +288,7 @@ class QByteArrayFormatter(HiddenMemberProvider):
                                                          self._char_type)
                 self._addChild(var)
 
-            # first replace " to \", and suround by "", no need to escape other things which
+            # first replace " to \", and surround by "", no need to escape other things which
             # are handled in printableQByteArray.
             printable = b'"{}"'.format(printable.replace(b'"', b'\\"'))
             self._addChild(('(content)', printable), hidden=True)
@@ -698,14 +686,14 @@ class BasicMapFormatter(HiddenMemberProvider):
 
 
 class QMapFormatter(BasicMapFormatter):
-    """lldb synthethic provider for QMap"""
+    """lldb synthetic provider for QMap"""
 
     def __init__(self, valobj, internal_dict):
         super(QMapFormatter, self).__init__(valobj, internal_dict)
 
 
 class QMultiMapFormatter(BasicMapFormatter):
-    """lldb synthethic provider for QMap"""
+    """lldb synthetic provider for QMap"""
 
     def __init__(self, valobj, internal_dict):
         super(QMultiMapFormatter, self).__init__(valobj.GetChildAtIndex(0), internal_dict)
@@ -811,14 +799,14 @@ class BasicHashFormatter(HiddenMemberProvider):
 
 
 class QHashFormatter(BasicHashFormatter):
-    """lldb synthethic provider for QHash"""
+    """lldb synthetic provider for QHash"""
 
     def __init__(self, valobj, internal_dict):
         super(QHashFormatter, self).__init__(valobj, internal_dict)
 
 
 class QMultiHashFormatter(BasicHashFormatter):
-    """lldb synthethic provider for QHash"""
+    """lldb synthetic provider for QHash"""
 
     def __init__(self, valobj, internal_dict):
         super(QMultiHashFormatter, self).__init__(valobj.GetChildAtIndex(0), internal_dict)
