@@ -16,6 +16,7 @@
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <KNSWidgets/Button>
+#include <kio_version.h>
 
 #include "ui_qthelpconfig.h"
 #include "ui_qthelpconfigeditdialog.h"
@@ -42,6 +43,11 @@ public:
         , m_config(parent)
     {
         setupUi(this);
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
+        qchRequester->setNameFilter(i18n("Qt Compressed Help Files") + QLatin1String(" (*.qch)"));
+#else
+        qchRequester->setFilter(QLatin1String("*.qch|") + i18n("Qt Compressed Help Files"));
+#endif
 
         if (modifiedItem) {
             setWindowTitle(i18nc("@title:window", "Modify Entry"));
@@ -346,3 +352,4 @@ QTreeWidgetItem * QtHelpConfig::addTableItem(const QString &icon, const QString
 }
 
 #include "qthelpconfig.moc"
+#include "moc_qthelpconfig.cpp"
